@@ -33,7 +33,7 @@ from calculate.install import distr
 import calculate.lib.utils.device as device
 from calculate.lib.utils.device import humanreadableSize
 from calculate.lib.utils.files import (process, typeFile,
-                                       listDirectory,
+                                       listDirectory, isEmpty,
                                        pathJoin, readFile, check_rw)
 from calculate.lib.utils.mount import isMount
 from calculate.lib.utils.kernel import InitrdFile
@@ -305,10 +305,11 @@ class VariableClBuilderDiskDev(Variable):
                 else:
                     dn = base_name
                 full_dn = path.join(default_path, dn)
-                if ((not path.exists(full_dn) or not isMount(full_dn)) and
-                            ds is None or
+                if ((not path.exists(full_dn) or not isMount(full_dn)
+                     and isEmpty(full_dn)) and
+                            (ds is None or
                             isinstance(ds, DriveSpool) and
-                            ds.lock_device(full_dn)):
+                            ds.lock_device(full_dn))):
                     return full_dn
             else:
                 return ""
